@@ -14,7 +14,7 @@ use Data::Dumper qw/Dumper/;
 use English qw/ -no_match_vars /;
 use base qw/Exporter/;
 
-our $VERSION     = version->new('0.0.2');
+our $VERSION     = version->new('0.0.4');
 our @EXPORT_OK   = qw//;
 our %EXPORT_TAGS = ();
 
@@ -70,7 +70,17 @@ sub exec {
 
 	my $cmd = $self->exe;
 
-	return CORE::exec( $cmd, @args );
+	my $run = join ' ', $cmd, @args;
+	return defined wantarray ? `$run` : CORE::exec($run);
+}
+
+sub cat {
+	my ($self, $file, $revision) = @_;
+
+	my $exe = $self->exe;
+	my $rev = $revision ? "-r$revision " : '';
+
+	return `$exe cat $rev$file`;
 }
 
 1;
@@ -83,7 +93,7 @@ VCS::Which::Plugin - Base class for the various VCS plugins
 
 =head1 VERSION
 
-This documentation refers to VCS::Which::Plugin version 0.0.2.
+This documentation refers to VCS::Which::Plugin version 0.0.4.
 
 
 =head1 SYNOPSIS
@@ -170,7 +180,25 @@ Description: Determines if the directory has no uncommitted changes
 Param: C<@params> - array of strings - The parameters that you wish to pass
 on to the vcs program.
 
-Description: Runs a command for the appropriate vcs.
+Description: Runs a command for the appropriate vcs. In void context it
+actually exec()s the command so never returns if the context is scalar or
+array backticks are used to run the command and the results are returned to
+the caller.
+
+=head3 C<cat ( $file[, $revision] )>
+
+Param: C<$file> - string - The name of the file to cat
+
+Param: C<$revision> - string - The revision to get. If the revision is negative
+it refers to the number of revisions old is desired. Any other value is
+assumed to be a version control specific revision. If no revision is specified
+the most recent revision is returned.
+
+Return: The file contents of the desired revision
+
+Description: Gets the contents of a specific revision of a file. This
+implementation works for many version control systems so may not be overloaded
+by specific plugins
 
 =head1 DIAGNOSTICS
 
